wipe-cli-0.1.2 is not a library.
The wipe binary: parse arguments, dispatch to a command, and translate any
error into a clean exit code (and, in --json mode, a machine-readable error
object on stdout).
The wipe binary: parse arguments, dispatch to a command, and translate any
error into a clean exit code (and, in --json mode, a machine-readable error
object on stdout).